@@ -73,9 +73,11 @@ public:
     QWebEngineDownloadItem::DownloadState downloadState;
     QWebEngineDownloadItem::SavePageFormat savePageFormat;
     QWebEngineDownloadItem::DownloadType type;
+    QWebEngineDownloadItem::DownloadInterruptReason interruptReason;
     QString downloadPath;
     const QUrl downloadUrl;
     QString mimeType;
+    bool downloadPaused;
 
     qint64 totalBytes;
     qint64 receivedBytes;
